Method: Spider::Model::Element#integrated_from_element

Defined in:
lib/spiderfw/model/element.rb

#integrated_from_elementObject

If the element is integrated, the element corresponding to this in the model corresponding to the #integrated_from element. See also #integrated?.



89
90
91
# File 'lib/spiderfw/model/element.rb', line 89

def integrated_from_element
    self.attributes[:integrated_from_element]
end